@@ -111,7 +111,7 @@ def copy_cfg_files(
             # Use the custom files defined in the repo
             _logger.warning("Using custom file %s", dst)
             continue
-        with open(src, "r") as fsrc, open(dst, "w") as fdst:
+        with open(src) as fsrc, open(dst, "w") as fdst:
             for line in fsrc:
                 if fname.startswith(".pre-commit-config") and "# EXCLUDE_LINT" in line:
                     line = ""
@@ -127,7 +127,7 @@ def copy_cfg_files(
                     )
                     line = line.replace("R0000", ",".join(pylint_disable_checks))
                 if fname == "pyproject.toml" and line.startswith("skip-string-normalization"):
-                    line = "skip-string-normalization=%s" % (skip_string_normalization and "true" or "false")
+                    line = "skip-string-normalization=%s\n" % (skip_string_normalization and "true" or "false")
                 if fname.startswith(".pylintrc"):
                     if "# External scripts odoo_lint replace" in line and odoo_version:
                         line += "valid-odoo-version=%s\n" % odoo_version
